import { Validator, AsyncValidator } from './validators/validateSatisfy';
class Expect {
    private value;
    private negated;
    constructor(value: any);
    /**
     * Negates a verifier. The negated verifier fails when the normal would pass
     * and passes when the normal would fail.
     */
    readonly not: this;
    /**
     * Performs a recursive (deep) equality check. Uses `Object.is` instead of
     * the strict equality operator (`===`). Supports expectations.
     * @param expected value to be recursively compared.
     */
    toEqual(expected: any): void;
    /**
     * Performs a strict equality check (using the `===` operator).
     * @param expected value to be checked against.
     */
    toStrictlyEqual(expected: any): void;
    /**
     * Checks is the value is instance of a given class. Uses the `instanceof`
     * operator.
     * @param constructor target class constructor.
     */
    toBeInstanceOf(constructor: Function): void;
    /**
     * Checks if the value is of a given type. Uses the `typeof` operator.
     * @param type target type.
     */
    toHaveTypeOf(type: string): void;
    /**
     * Checks if the value is truthy (`!!value === true`).
     */
    toBeTruthy(): void;
    /**
     * Checks if the value is falsy (`!!value === false`).
     */
    toBeFalsy(): void;
    /**
     * Checks if the value is a number greater than target.
     * @param target number to compare the value to.
     */
    toBeGreaterThan(target: number): void;
    /**
     * Checks if the value is a number greater than or equal to target.
     * @param target number to compare the value to.
     */
    toBeGreaterThanOrEqual(target: number): void;
    /**
     * Checks if the value is a number less than target.
     * @param target number to compare the value to.
     */
    toBeLessThan(target: number): void;
    /**
     * Checks if the value is a number less than or equal to target.
     * @param target number to compare the value to.
     */
    toBeLessThanOrEqual(target: number): void;
    /**
     * Checks if the value is a number close to target within a given precision.
     * @param target number to compare the value to.
     * @param precision (optional) desired precision
     */
    toBeCloseTo(target: number, precision?: number): void;
    /**
     * Checks if the value is a `mockFn` that has been called at least once.
     */
    toBeCalled(): void;
    /**
     * Checks if the value is a `mockFn` that has been called a specific number of
     * times.
     * @param count number of times the `mockFn` has to be called.
     */
    toBeCalledTimes(count: number): void;
    /**
     * Checks if the value is a `mockFn` that has been called a most recently
     * with the specified arguments.
     * @param count number of times the `mockFn` has to be called.
     */
    toBeCalledWith(...args: any[]): void;
    /**
     * Checks that the value passes the test in the form of a given function.
     * @param validator function that processes the value.
     */
    toSatisfy(validator: Validator): void;
    toSatisfy(validator: AsyncValidator): Promise<void>;
}
export declare function expect(value: any): Expect;
export declare namespace expect {
    /**
     * Always succeeds.
     */
    const anything: () => import("./expectation").Expectation;
    /**
     * Checks is the value is instance of a given class. Uses the `instanceof`
     * operator.
     * @param constructor target class constructor.
     */
    const toBeInstanceOf: (constructor: Function) => import("./expectation").Expectation;
    /**
     * Checks if the value is of a given type. Uses the `typeof` operator.
     * @param type target type.
     */
    const toHaveTypeOf: (type: string) => import("./expectation").Expectation;
    /**
     * Checks if the value is truthy (`!!value === true`).
     */
    const toBeTruthy: () => import("./expectation").Expectation;
    /**
     * Checks if the value is falsy (`!!value === false`).
     */
    const toBeFalsy: () => import("./expectation").Expectation;
    /**
     * Checks if the value is a number greater than target.
     * @param target number to compare the value to.
     */
    const toBeGreaterThan: (target: number) => import("./expectation").Expectation;
    /**
     * Checks if the value is a number greater than or equal to target.
     * @param target number to compare the value to.
     */
    const toBeGreaterThanOrEqual: (target: number) => import("./expectation").Expectation;
    /**
     * Checks if the value is a number less than target.
     * @param target number to compare the value to.
     */
    const toBeLessThan: (target: number) => import("./expectation").Expectation;
    /**
     * Checks if the value is a number less than or equal to target.
     * @param target number to compare the value to.
     */
    const toBeLessThanOrEqual: (target: number) => import("./expectation").Expectation;
    /**
     * Checks if the value is a number close to target within a given precision.
     * @param target number to compare the value to.
     * @param precision (optional) desired precision
     */
    const toBeCloseTo: (target: number, precision?: number | undefined) => import("./expectation").Expectation;
    /**
     * Checks that the value passes the test in the form of a given function.
     * @param validator function that processes the value.
     */
    const toSatisfy: (validator: Validator) => import("./expectation").Expectation;
    /**
     * Negates an expectation. The negated expectaiton fails when the normal would
     * pass and passes when the normal would fail.
     */
    namespace not {
        /**
         * Always succeeds.
         */
        const anything: () => import("./expectation").Expectation;
        /**
         * Checks is the value is instance of a given class. Uses the `instanceof`
         * operator.
         * @param constructor target class constructor.
         */
        const toBeInstanceOf: (constructor: Function) => import("./expectation").Expectation;
        /**
         * Checks if the value is of a given type. Uses the `typeof` operator.
         * @param type target type.
         */
        const toHaveTypeOf: (type: string) => import("./expectation").Expectation;
        /**
         * Checks if the value is truthy (`!!value === true`).
         */
        const toBeTruthy: () => import("./expectation").Expectation;
        /**
         * Checks if the value is falsy (`!!value === false`).
         */
        const toBeFalsy: () => import("./expectation").Expectation;
        /**
         * Checks if the value is a number greater than target.
         * @param target number to compare the value to.
         */
        const toBeGreaterThan: (target: number) => import("./expectation").Expectation;
        /**
         * Checks if the value is a number greater than or equal to target.
         * @param target number to compare the value to.
         */
        const toBeGreaterThanOrEqual: (target: number) => import("./expectation").Expectation;
        /**
         * Checks if the value is a number less than target.
         * @param target number to compare the value to.
         */
        const toBeLessThan: (target: number) => import("./expectation").Expectation;
        /**
         * Checks if the value is a number less than or equal to target.
         * @param target number to compare the value to.
         */
        const toBeLessThanOrEqual: (target: number) => import("./expectation").Expectation;
        /**
         * Checks if the value is a number close to target within a given precision.
         * @param target number to compare the value to.
         * @param precision (optional) desired precision
         */
        const toBeCloseTo: (target: number, precision?: number | undefined) => import("./expectation").Expectation;
        /**
         * Checks that the value passes the test in the form of a given function.
         * @param validator function that processes the value.
         */
        const toSatisfy: (validator: Validator) => import("./expectation").Expectation;
    }
}
export {};
