"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var validateSatisfy_1 = require("./validators/validateSatisfy");
var validateEqual_1 = require("./validators/validateEqual");
var validateStrictlyEqual_1 = require("./validators/validateStrictlyEqual");
var validateInstanceOf_1 = require("./validators/validateInstanceOf");
var validateTypeOf_1 = require("./validators/validateTypeOf");
var validateTruthy_1 = require("./validators/validateTruthy");
var validateFalsy_1 = require("./validators/validateFalsy");
var validateGreaterThan_1 = require("./validators/validateGreaterThan");
var validateGreaterThanOrEqual_1 = require("./validators/validateGreaterThanOrEqual");
var validateLessThan_1 = require("./validators/validateLessThan");
var validateLessThanOrEqual_1 = require("./validators/validateLessThanOrEqual");
var validateCloseTo_1 = require("./validators/validateCloseTo");
var validateCalled_1 = require("./validators/validateCalled");
var validateCalledTimes_1 = require("./validators/validateCalledTimes");
var validateCalledWith_1 = require("./validators/validateCalledWith");
var expectation_1 = require("./expectation");
var Expect = /** @class */ (function () {
    function Expect(value) {
        this.negated = false;
        this.value = value;
    }
    Object.defineProperty(Expect.prototype, "not", {
        /**
         * Negates a verifier. The negated verifier fails when the normal would pass
         * and passes when the normal would fail.
         */
        get: function () {
            if (!this.negated) {
                this.negated = true;
            }
            else {
                throw new TypeError('Cannot negate an already negated validator.');
            }
            return this;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Performs a recursive (deep) equality check. Uses `Object.is` instead of
     * the strict equality operator (`===`). Supports expectations.
     * @param expected value to be recursively compared.
     */
    Expect.prototype.toEqual = function (expected) {
        return this.toSatisfy(validateEqual_1.validateEqual(expected));
    };
    /**
     * Performs a strict equality check (using the `===` operator).
     * @param expected value to be checked against.
     */
    Expect.prototype.toStrictlyEqual = function (expected) {
        return this.toSatisfy(validateStrictlyEqual_1.validateStrictlyEqual(expected));
    };
    /**
     * Checks is the value is instance of a given class. Uses the `instanceof`
     * operator.
     * @param constructor target class constructor.
     */
    Expect.prototype.toBeInstanceOf = function (constructor) {
        return this.toSatisfy(validateInstanceOf_1.validateInstanceOf(constructor));
    };
    /**
     * Checks if the value is of a given type. Uses the `typeof` operator.
     * @param type target type.
     */
    Expect.prototype.toHaveTypeOf = function (type) {
        return this.toSatisfy(validateTypeOf_1.validateTypeOf(type));
    };
    /**
     * Checks if the value is truthy (`!!value === true`).
     */
    Expect.prototype.toBeTruthy = function () {
        return this.toSatisfy(validateTruthy_1.validateTruthy);
    };
    /**
     * Checks if the value is falsy (`!!value === false`).
     */
    Expect.prototype.toBeFalsy = function () {
        return this.toSatisfy(validateFalsy_1.validateFalsy);
    };
    /**
     * Checks if the value is a number greater than target.
     * @param target number to compare the value to.
     */
    Expect.prototype.toBeGreaterThan = function (target) {
        return this.toSatisfy(validateGreaterThan_1.validateGreaterThan(target));
    };
    /**
     * Checks if the value is a number greater than or equal to target.
     * @param target number to compare the value to.
     */
    Expect.prototype.toBeGreaterThanOrEqual = function (target) {
        return this.toSatisfy(validateGreaterThanOrEqual_1.validateGreaterThanOrEqual(target));
    };
    /**
     * Checks if the value is a number less than target.
     * @param target number to compare the value to.
     */
    Expect.prototype.toBeLessThan = function (target) {
        return this.toSatisfy(validateLessThan_1.validateLessThan(target));
    };
    /**
     * Checks if the value is a number less than or equal to target.
     * @param target number to compare the value to.
     */
    Expect.prototype.toBeLessThanOrEqual = function (target) {
        return this.toSatisfy(validateLessThanOrEqual_1.validateLessThanOrEqual(target));
    };
    /**
     * Checks if the value is a number close to target within a given precision.
     * @param target number to compare the value to.
     * @param precision (optional) desired precision
     */
    Expect.prototype.toBeCloseTo = function (target, precision) {
        return this.toSatisfy(validateCloseTo_1.validateCloseTo(target, precision));
    };
    /**
     * Checks if the value is a `mockFn` that has been called at least once.
     */
    Expect.prototype.toBeCalled = function () {
        return this.toSatisfy(validateCalled_1.validateCalled);
    };
    /**
     * Checks if the value is a `mockFn` that has been called a specific number of
     * times.
     * @param count number of times the `mockFn` has to be called.
     */
    Expect.prototype.toBeCalledTimes = function (count) {
        return this.toSatisfy(validateCalledTimes_1.validateCalledTimes(count));
    };
    /**
     * Checks if the value is a `mockFn` that has been called a most recently
     * with the specified arguments.
     * @param count number of times the `mockFn` has to be called.
     */
    Expect.prototype.toBeCalledWith = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        return this.toSatisfy(validateCalledWith_1.validateCalledWith(args));
    };
    Expect.prototype.toSatisfy = function (validator) {
        return validateSatisfy_1.validateSatisfy(this.value, this.negated, validator);
    };
    return Expect;
}());
function expect(value) {
    return new Expect(value);
}
exports.expect = expect;
(function (expect) {
    /**
     * Always succeeds.
     */
    expect.anything = function () { return expectation_1.createExpectation(false, function () { return true; }); };
    /**
     * Checks is the value is instance of a given class. Uses the `instanceof`
     * operator.
     * @param constructor target class constructor.
     */
    expect.toBeInstanceOf = function (constructor) {
        return expectation_1.createExpectation(false, validateInstanceOf_1.validateInstanceOf(constructor));
    };
    /**
     * Checks if the value is of a given type. Uses the `typeof` operator.
     * @param type target type.
     */
    expect.toHaveTypeOf = function (type) {
        return expectation_1.createExpectation(false, validateTypeOf_1.validateTypeOf(type));
    };
    /**
     * Checks if the value is truthy (`!!value === true`).
     */
    expect.toBeTruthy = function () { return expectation_1.createExpectation(false, validateTruthy_1.validateTruthy); };
    /**
     * Checks if the value is falsy (`!!value === false`).
     */
    expect.toBeFalsy = function () { return expectation_1.createExpectation(false, validateFalsy_1.validateFalsy); };
    /**
     * Checks if the value is a number greater than target.
     * @param target number to compare the value to.
     */
    expect.toBeGreaterThan = function (target) {
        return expectation_1.createExpectation(false, validateGreaterThan_1.validateGreaterThan(target));
    };
    /**
     * Checks if the value is a number greater than or equal to target.
     * @param target number to compare the value to.
     */
    expect.toBeGreaterThanOrEqual = function (target) {
        return expectation_1.createExpectation(false, validateGreaterThanOrEqual_1.validateGreaterThanOrEqual(target));
    };
    /**
     * Checks if the value is a number less than target.
     * @param target number to compare the value to.
     */
    expect.toBeLessThan = function (target) {
        return expectation_1.createExpectation(false, validateLessThan_1.validateLessThan(target));
    };
    /**
     * Checks if the value is a number less than or equal to target.
     * @param target number to compare the value to.
     */
    expect.toBeLessThanOrEqual = function (target) {
        return expectation_1.createExpectation(false, validateLessThanOrEqual_1.validateLessThanOrEqual(target));
    };
    /**
     * Checks if the value is a number close to target within a given precision.
     * @param target number to compare the value to.
     * @param precision (optional) desired precision
     */
    expect.toBeCloseTo = function (target, precision) {
        return expectation_1.createExpectation(false, validateCloseTo_1.validateCloseTo(target, precision));
    };
    /**
     * Checks that the value passes the test in the form of a given function.
     * @param validator function that processes the value.
     */
    expect.toSatisfy = function (validator) {
        return expectation_1.createExpectation(false, validator);
    };
    /**
     * Negates an expectation. The negated expectaiton fails when the normal would
     * pass and passes when the normal would fail.
     */
    var not;
    (function (not) {
        /**
         * Always succeeds.
         */
        not.anything = function () { return expectation_1.createExpectation(true, function () { return true; }); };
        /**
         * Checks is the value is instance of a given class. Uses the `instanceof`
         * operator.
         * @param constructor target class constructor.
         */
        not.toBeInstanceOf = function (constructor) {
            return expectation_1.createExpectation(true, validateInstanceOf_1.validateInstanceOf(constructor));
        };
        /**
         * Checks if the value is of a given type. Uses the `typeof` operator.
         * @param type target type.
         */
        not.toHaveTypeOf = function (type) {
            return expectation_1.createExpectation(true, validateTypeOf_1.validateTypeOf(type));
        };
        /**
         * Checks if the value is truthy (`!!value === true`).
         */
        not.toBeTruthy = function () { return expectation_1.createExpectation(true, validateTruthy_1.validateTruthy); };
        /**
         * Checks if the value is falsy (`!!value === false`).
         */
        not.toBeFalsy = function () { return expectation_1.createExpectation(true, validateFalsy_1.validateFalsy); };
        /**
         * Checks if the value is a number greater than target.
         * @param target number to compare the value to.
         */
        not.toBeGreaterThan = function (target) {
            return expectation_1.createExpectation(true, validateGreaterThan_1.validateGreaterThan(target));
        };
        /**
         * Checks if the value is a number greater than or equal to target.
         * @param target number to compare the value to.
         */
        not.toBeGreaterThanOrEqual = function (target) {
            return expectation_1.createExpectation(true, validateGreaterThanOrEqual_1.validateGreaterThanOrEqual(target));
        };
        /**
         * Checks if the value is a number less than target.
         * @param target number to compare the value to.
         */
        not.toBeLessThan = function (target) {
            return expectation_1.createExpectation(true, validateLessThan_1.validateLessThan(target));
        };
        /**
         * Checks if the value is a number less than or equal to target.
         * @param target number to compare the value to.
         */
        not.toBeLessThanOrEqual = function (target) {
            return expectation_1.createExpectation(true, validateLessThanOrEqual_1.validateLessThanOrEqual(target));
        };
        /**
         * Checks if the value is a number close to target within a given precision.
         * @param target number to compare the value to.
         * @param precision (optional) desired precision
         */
        not.toBeCloseTo = function (target, precision) {
            return expectation_1.createExpectation(true, validateCloseTo_1.validateCloseTo(target, precision));
        };
        /**
         * Checks that the value passes the test in the form of a given function.
         * @param validator function that processes the value.
         */
        not.toSatisfy = function (validator) {
            return expectation_1.createExpectation(true, validator);
        };
    })(not = expect.not || (expect.not = {}));
})(expect = exports.expect || (exports.expect = {}));
